<?php
/**
 * Deoblog Theme Customizer
 *
 * @package Deoblog lite
 */


function deoblog_lite_customize_register( $wp_customize ) {

  // Customize Background Settings
  $wp_customize->get_section('background_image')->title = esc_html__('Background Styles', 'deoblog-lite');  
  $wp_customize->get_control('background_color')->section = 'background_image';


  // Custom Logo
  $wp_customize->add_section( 'deoblog_lite_custom_logo', array(
    'title'       => esc_html__('Add Logo', 'deoblog-lite' ),
    'panel'       => 'design_settings',
    'priority'    => 20,
    'description' => esc_html__('Upload your custom logo', 'deoblog-lite')
  ) );

  $wp_customize->add_setting( 'deoblog_lite_logo', array(
    array(
      'sanitize_callback' => 'wp_filter_nohtml_kses' //removes all HTML from content
    )
  ) );

  $wp_customize->add_control(
    new WP_Customize_Image_Control(
      $wp_customize,
      'deoblog_lite_custom_logo',
      array(
        'label'     => esc_html__( 'Upload logo', 'deoblog-lite' ),
        'section'   => 'title_tagline',
        'settings'  => 'deoblog_lite_logo',
        'context'   => 'deoblog_lite_custom_logo'
      )
    )
  );


  // Footer Copyright
  $wp_customize->add_setting( 'deoblog_lite_footer_bottom_text', array(
    'capability' => 'edit_theme_options',
    'default' => sprintf(esc_html__( ' DeoBlog, made by %1$sDeoThemes%2$s' , 'deoblog-lite' ),
    '<a href="https://deothemes.com">',
    '</a>'),
    'sanitize_callback' => 'deoblog_lite_sanitize_html',
   ) );

  $wp_customize->add_control( 'deoblog_lite_footer_bottom_text', array(
    'type'        => 'text',
    'section'     => 'deoblog_lite_footer',
    'label'       => esc_html__( 'Footer bottom text', 'deoblog-lite' ),
    'description' => esc_html__( 'You can use HTML: a, span, i, em, strong', 'deoblog-lite' ),
    'priority'    => 30,
  ) );

  // Remove Custom Header Section
  $wp_customize->remove_section('header_image');
  $wp_customize->remove_section('colors');
}
add_action( 'customize_register', 'deoblog_lite_customize_register' );

// Check if Kirki is installed
if ( class_exists( 'Kirki' ) ) {

  // Selector Vars 
  $selector = array(
    'main_color'      => '
        a,
        a:focus,
        blockquote > span,
        .entry-title a:hover,
        .entry-meta li a:hover,
        .widget_categories li a:hover,
        .entry-tags a:hover,
        .comment-edit-link,
        .widget ul li a:hover,
        .entry-navigation a:hover,
        .recent-posts-title a:hover
    ',
    'main_background_color' => '
        .nav-icon-toggle:focus .nav-icon-toggle-bar,
        .nav-icon-toggle:hover .nav-icon-toggle-bar,
        #back-to-top:hover,
        .pagination-link > a:hover,
        .widget_tag_cloud a:hover,
        .btn-transparent:hover,
        .btn-white:hover,
        .btn-stroke:hover,
        .btn-color,
        .btn-light:hover,
        .social-icons a:hover,
        .btn-button.btn-color,
        .footer.bg-dark .widget_tag_cloud a:hover,
        .footer.bg-dark .social-icons a:hover,
        .mc4wp-form-fields input[type=submit],
        .hero__entry__category
    ',
    'main_border_color' => '
        input:focus,
        textarea:focus
    ',
    'headings_color'  => 'h1,h2,h3,h4,h5,h6',
    'text_color'  => 'body, p',
    'meta_color'  => '.entry-meta li',
    'footer_widgets_text_color' =>
      '.footer,
      .footer-widgets .widget,
      .footer-widgets .widget ul li a,
      .footer-widgets a,
      .footer-widgets p',

    'headings'        => 'h1,h2,h3,h4,h5,h6',  
    'h1'              => 'h1',
    'h2'              => 'h2',
    'h3'              => 'h3',
    'h4'              => 'h4',
    'h5'              => 'h5',
    'h6'              => 'h6',
    'text'            => '.entry-content p, .entry-article p',
  );


  // Kirki
  Kirki::add_config( 'deoblog_lite_config', array(
    'capability'    => 'edit_theme_options',
    'option_type'   => 'theme_mod',
    'option_name'   => 'deoblog_lite_config',
  ) );


  /**
  * SECTIONS
  **/

  $priority = 20;

  // Posts
  Kirki::add_section( 'deoblog_lite_posts', array(
    'title'          => esc_html__( 'Posts', 'deoblog-lite' ),
    'description'    => esc_html__( 'Posts options', 'deoblog-lite' ),
    'priority'       => $priority++,
  ) );  

  // COLORS PANEL
  Kirki::add_panel( 'deoblog_lite_colors', array(
    'title'          => esc_html__( 'Colors', 'deoblog-lite' ),
    'priority'       => $priority++,
  ) );

    // General Colors
    Kirki::add_section( 'deoblog_lite_general_colors', array(
      'title'  => esc_html__( 'General Colors', 'deoblog-lite' ),
      'panel'	 => 'deoblog_lite_colors',
    ) );

    // HEADER COLORS PANEL
    Kirki::add_section( 'deoblog_lite_header_colors', array(
      'title'  => esc_html__( 'Header Colors', 'deoblog-lite' ),
      'panel'  => 'deoblog_lite_colors',
    ) );

    // FOOTER COLORS PANEL
    Kirki::add_section( 'deoblog_lite_footer_colors', array(
      'title'  => esc_html__( 'Footer Colors', 'deoblog-lite' ),
      'panel'  => 'deoblog_lite_colors',
    ) );
  
  // Typography
  Kirki::add_section( 'deoblog_lite_typography', array(
    'title'          => esc_html__( 'Typography', 'deoblog-lite' ),
    'priority'       => $priority++,
  ) );

  Kirki::add_section( 'deoblog_lite_header', array(
    'title'          => esc_html__( 'Header', 'deoblog-lite' ),
    'description'    => esc_html__( 'Header options', 'deoblog-lite' ),
    'priority'       => $priority++,
  ) );

  Kirki::add_section( 'deoblog_lite_footer', array(
    'title'          => esc_html__( 'Footer', 'deoblog-lite' ),
    'description'    => esc_html__( 'Footer options', 'deoblog-lite' ),
    'priority'       => $priority++,
  ) );


  /**
  * CONTROLS
  **/

  // Posts Excerpt control
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'number',
    'settings'    => 'deoblog_lite_posts_excerpt_settings',
    'label'       => esc_html__( 'Posts excerpt options', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_posts',
    'default'     => 55,
    'priority'    => 10,
    'choices'     => array(
      'min'  => 0,
      'max'  => 9999,
      'step' => 1,
    ),
  ) );


  // Footer widgets control
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'select',
    'settings'    => 'deoblog_lite_footer_widgets_settings',
    'label'       => esc_html__( 'How many widgets to show', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_footer',
    'default'     => 'four_col',
    'priority'    => 10,
    'choices'     => array(
      'one_col'    => esc_attr__( 'One Column', 'deoblog-lite' ),
      'two_col'    => esc_attr__( 'Two Columns', 'deoblog-lite' ),
      'three_col'  => esc_attr__( 'Three Columns', 'deoblog-lite' ),
      'four_col'   => esc_attr__( 'Four Columns', 'deoblog-lite' ),
    ),
  ) );

  // Back to top control
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'checkbox',
    'settings'    => 'deoblog_lite_back_to_top_settings',
    'label'       => esc_html__( 'Back to top arrow', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_footer',
    'default'     => 1,
    'priority'    => 20,
  ) );


  // Sticky nav control
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'checkbox',
    'settings'    => 'deoblog_lite_sticky_nav_settings',
    'label'       => esc_html__( 'Sticky Navbar', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_header',
    'default'     => 1,
    'priority'    => 20,
  ) );


  /********************************
  * Colors
  ********************************/

  // Main color control
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_color_settings',
    'label'       => esc_html__( 'Main accent color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_general_colors',
    'default'     => '#2eb84c',
    'output' => array(
      array(
        'element'  => $selector['main_color'],
        'property' => 'color',
      ),
      array(
        'element' => $selector['main_background_color'],
        'property' => 'background-color',
      ),
      array(
        'element' => $selector['main_border_color'],
        'property' => 'border-color',
      ),
    ),
  ) );

  // Headings color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_headings_color',
    'label'       => esc_html__( 'Headings color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_general_colors',
    'default'     => '#121212',
    'output' => array(
      array(
        'element'  => $selector['headings_color'],
        'property' => 'color',
      ),
    ),
  ) );

  // Text color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_text_color',
    'label'       => esc_html__( 'Text color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_general_colors',
    'default'     => '#696e6f',
    'output' => array(
      array(
        'element'  => $selector['text_color'],
        'property' => 'color',
      ),
    )
  ) );

  // Header background color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_header_background_color',
    'label'       => esc_html__( 'Header background color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_header_colors',
    'default'     => 'rgba(22,25,29,1)',
    'choices'     => array(
      'alpha' => true,
    ),
    'output' => array(
      array(
        'element'     => '.nav-dark, .nav-holder.sticky',
        'property'    => 'background-color',
      ),
    )
  ) );

  // Logo color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_header_logo_color',
    'label'       => esc_html__( 'Logo color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_header_colors',
    'default'     => '#ffffff',
    'output' => array(
      array(
        'element'     => '.site-logo',
        'property'    => 'color',
      ),			
    )
  ) );

  // Menu links color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_header_menu_links_color',
    'label'       => esc_html__( 'Menu links color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_header_colors',
    'default'     => '#a6afbb',
    'output' => array(
      array(
        'element'     => '.nav-menu > li > a, .nav-right',
        'property'    => 'color',
      ),			
    )
  ) );

  // Menu links hover color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_header_menu_links_hover_color',
    'label'       => esc_html__( 'Menu links hover color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_header_colors',
    'default'     => '#ffffff',
    'output' => array(
      array(
        'element'     => '.nav-menu > li > a:hover, .nav-menu > li > a:focus, .nav-search-link:hover, .nav-search-link:focus',
        'property'    => 'color',
      ),			
    )
  ) );

  // Dropdown background color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_header_dropdown_background_color',
    'label'       => esc_html__( 'Dropdown background color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_header_colors',
    'default'     => '#1a1e23',
    'output' => array(
      array(
        'element'     => '.nav-dropdown-menu, .nav-dropdown-submenu > .nav-dropdown-menu',
        'property'    => 'background-color',
      ),
    )
  ) );

  // Dropdown menu links color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_header_dropdown_menu_links_color',
    'label'       => esc_html__( 'Dropdown menu links color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_header_colors',
    'default'     => '#a6afbb',
    'output' => array(
      array(
        'element'     => '.nav-dropdown-menu > li > a, .nav-dropdown-submenu > .nav-dropdown-menu > li > a',
        'property'    => 'color',
      ),
    )
  ) );

  // Dropdown menu links hover color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_header_dropdown_menu_links_hover_color',
    'label'       => esc_html__( 'Dropdown menu links hover color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_header_colors',
    'default'     => '#ffffff',
    'output' => array(
      array(
        'element'     => '.nav-dropdown-menu > li > a:hover, .nav-dropdown-menu > li > a:focus, .nav-dropdown-submenu > .nav-dropdown-menu > li > a:hover, .nav-dropdown-submenu > .nav-dropdown-menu > li > a:focus',
        'property'    => 'color',
      ),
    )
  ) );

  // Dropdown menu links hover background color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_header_dropdown_menu_links_hover_background_color',
    'label'       => esc_html__( 'Dropdown menu links hover background color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_header_colors',
    'default'     => '#1f2329',
    'output' => array(
      array(
        'element'     => '.nav-dropdown-menu > li a:hover, .nav-dropdown-menu > li a:focus',
        'property'    => 'background-color',
      ),
    )
  ) );

  // Mobile menu dividers color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_header_mobile_menu_dividers_color',
    'label'       => esc_html__( 'Mobile menu dividers color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_header_colors',
    'default'     => 'rgba(43,47,53,1)',
    'choices'     => array(
      'alpha' => true,
    ),
    'output' => array(
      array(
        'element'     => '.nav-menu li a',
        'property'    => 'border-bottom-color',
        'media_query' => '@media (max-width: 991px)',
      ),
    )
  ) );

  // Mobile Header menu toggle color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_header_mobile_menu_toggle_color',
    'label'       => esc_html__( 'Mobile menu toggle color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_header_colors',
    'default'     => '#ffffff',
    'output' => array(
      array(
        'element'  => '.nav-dark .nav-icon-toggle-bar',
        'property' => 'background-color',
      ),
    )
  ) );


  /*-------------------------------------------------------*/
  /* Footer Colors
  /*-------------------------------------------------------*/

  // Footer background color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_footer_background_color',
    'label'       => esc_html__( 'Footer background color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_footer_colors',
    'default'     => '#16191d',
    'output' => array(
      array(
        'element'  => '.footer.bg-dark',
        'property' => 'background-color',
      ),
    )
  ) );

  // Footer widget title color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_footer_widgets_title_color',
    'label'       => esc_html__( 'Footer widgets title color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_footer_colors',
    'default'     => '#ffffff',
    'output' => array(
      array(
        'element'  => '.footer .widget-title',
        'property' => 'color',
      ),
    )
  ) );

  // Footer widget text color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_footer_widgets_text_color',
    'label'       => esc_html__( 'Footer widgets text color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_footer_colors',
    'default'     => '#a7afba',
    'output' => array(
      array(
        'element'  => $selector['footer_widgets_text_color'],
        'property' => 'color',
      ),
    )
  ) );

  // Footer widget links hover color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_footer_links_hover_color',
    'label'       => esc_html__( 'Footer links hover color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_footer_colors',
    'default'     => '#fffff',
    'output' => array(
      array(
        'element'  => '.footer.bg-dark .footer-widgets a:hover, .footer.bg-dark .footer-widgets a:focus, .footer.bg-dark .copyright a:hover, .footer.bg-dark .copyright a:focus',
        'property' => 'color',
      ),
    )
  ) );

  // Footer widget meta color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_footer_widgets_meta_color',
    'label'       => esc_html__( 'Footer widgets meta color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_footer_colors',
    'default'     => '#646a6d',
    'output' => array(
      array(
        'element'  => '.footer.bg-dark .widget_recent_entries .post-date',
        'property' => 'color',
      ),
    )
  ) );  

  // Footer bottom background color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_footer_bottom_background_color',
    'label'       => esc_html__( 'Footer bottom background color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_footer_colors',
    'default'     => '#111417',
    'output' => array(
      array(
        'element'  => '.footer-bottom',
        'property' => 'background-color',
      ),
    )
  ) );

  // Footer bottom text color
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'color',
    'settings'    => 'deoblog_lite_footer_bottom_text_color',
    'label'       => esc_html__( 'Footer bottom text color', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_footer_colors',
    'default'     => '#99a0aa',
    'output' => array(
      array(
        'element'  => '.footer-bottom',
        'property' => 'color',
      ),
    )
  ) );


  /********************************
  * Typography
  ********************************/

  // H1
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'typography',
    'settings'    => 'deoblog_lite_headings_h1',
    'label'       => esc_html__( 'H1 Headings', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_typography',
    'default'     => array(
      'font-family' => 'Rubik',
      'font-size'   => '36px',
      'font-weight' => '300',
      'line-height' => '1.4',
      'letter-spacing' => '-0.02em'
    ),
    'choices'  => array(
      'variant' => array(
        'regular',
        '700',
        'italic'			
      ),
    ),
    'output' => array(
      array(
        'element' => $selector['h1'],
      ),
    )
  ));

  // H2
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'typography',
    'settings'    => 'deoblog_lite_headings_h2',
    'label'       => esc_html__( 'H2 Headings', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_typography',
    'default'     => array(
      'font-family' => 'Rubik',
      'font-size'   => '30px',
      'font-weight' => '300',
      'line-height' => '1.4',
      'letter-spacing' => '-0.02em'
    ),
    'choices'  => array(
      'variant' => array(
        'regular',
        '700',
        'italic'			
      ),
    ),
    'output' => array(
      array(
        'element' => $selector['h2'],
      ),
    )
  ));

  // H3
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'typography',
    'settings'    => 'deoblog_lite_headings_h3',
    'label'       => esc_html__( 'H3 Headings', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_typography',
    'default'     => array(
      'font-family' => 'Rubik',
      'font-size'   => '24px',
      'font-weight' => '400',
      'line-height' => '1.4',
    ),
    'choices'  => array(
      'variant' => array(
        'regular',
        '700',
        'italic'			
      ),
    ),
    'output' => array(
      array(
        'element' => $selector['h3'],
      ),
    )
  ));

  // H4
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'typography',
    'settings'    => 'deoblog_lite_headings_h4',
    'label'       => esc_html__( 'H4 Headings', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_typography',
    'default'     => array(
      'font-family' => 'Rubik',
      'font-size'   => '20px',
      'font-weight' => '400',
      'line-height' => '1.4',
    ),
    'choices'  => array(
      'variant' => array(
        'regular',
        '700',
        'italic'			
      ),
    ),
    'output' => array(
      array(
        'element' => $selector['h4'],
      ),
    )
  ));

  // H5
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'typography',
    'settings'    => 'deoblog_lite_headings_h5',
    'label'       => esc_html__( 'H5 Headings', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_typography',
    'default'     => array(
      'font-family' => 'Rubik',
      'font-size'   => '18px',
      'font-weight' => '400',
      'line-height' => '1.4',
    ),
    'choices'  => array(
      'variant' => array(
        'regular',
        '700',
        'italic'			
      ),
    ),
    'output' => array(
      array(
        'element' => $selector['h5'],
      ),
    )
  ));

  // H6
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'typography',
    'settings'    => 'deoblog_lite_headings_h6',
    'label'       => esc_html__( 'H6 Headings', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_typography',
    'default'     => array(
      'font-family' => 'Rubik',
      'font-size'   => '16px',
      'font-weight' => '400',
      'line-height' => '1.4',
    ),
    'choices'  => array(
      'variant' => array(
        'regular',
        '700',
        'italic'			
      ),
    ),
    'output' => array(
      array(
        'element' => $selector['h6'],
      ),
    )
  ));

  // Body typography
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'typography',
    'settings'    => 'deoblog_lite_body_typography',
    'label'       => esc_html__( 'Body Typography', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_typography',
    'default'     => array(
      'font-family'    => 'Open Sans',
      'font-size'      => '16px',
      'line-height'    => '1.875',
    ),
    'choices'  => array(
      'variant' => array(
        '700',
        '500',
        'italic',
      ),
    ),
    'output' => array(
      array(
        'element' => $selector['text'],
      ),
    )
  ));

  // Menu Links typography
  Kirki::add_field( 'deoblog_lite_config', array(
    'type'        => 'typography',
    'settings'    => 'deoblog_lite_menu_links_typography',
    'label'       => esc_html__( 'Menu Links Typography', 'deoblog-lite' ),
    'section'     => 'deoblog_lite_typography',
    'default'     => array(
      'font-family' => 'Open Sans',
      'font-weight' => '400',
      'font-size'		=> '14px'
    ),
    'output' => array(
      array(
        'element' => '.nav-menu > li > a',
      ),
    )
  ));



} // endif Kirki check


//Sanitization settings
function deoblog_lite_sanitize_twitter_handler( $input ){
  $output = sanitize_text_field( $input );
  $output = str_replace('@', '', $output);
  return $output;
}


// Sanitize text 
function deoblog_lite_sanitize_text( $text ) {    
  return sanitize_text_field( $text );
}

function deoblog_lite_sanitize_html( $input ) {
  return wp_kses( $input, array(
    'a' => array(
      'href' => array(),
      'target' => array(),
    ),
    'i' => array(),
    'span' => array(),
    'em' => array(),
    'strong' => array(),
) );
};